@@ -74,7 +74,7 @@ class Shift_day_relax(BaseRef):
 
     @property
     def html(self):
-        descr = '' if self.description == None else f'({self.description})'
+        descr = '' if self.description is None else f'({self.description})'
         return f'<div><font color="{self.color}"><p><b>{self.name} {descr}</b></p>{self.period_html}</font></div>'
 
     objects = Shift_day_relaxManager()
