@@ -94,6 +94,8 @@ class LoginRequest(DSRequest):
                             jsLogDebug=settings.JS_LOG_DEBUG if settings.JS_LOG_DEBUG == 1 else 0,
                             KOMPAS_INFORMICA_WS=settings.KOMPAS_INFORMICA_WS,
                             KOMPAS_INFORMICA=settings.KOMPAS_INFORMICA,
+                            CKK_CONFIGURATOR=settings.CKK_CONFIGURATOR,
+                            ENABLE_FILE_VIEW=settings.ENABLE_FILE_VIEW,
                             login=login,
                             message_state_delivered_id=Messages_state.message_state_delivered().id,
                             message_state_delivered_name=Messages_state.message_state_delivered().name,
