@@ -244,7 +244,7 @@ class CommonQuerySet(QuerySet):
     def getValue(self, criterion):
         value = criterion.get('value')
         operator = criterion.get('operator')
-        if value == None:
+        if value is None:
             if operator == "isNull":
                 return True
             elif operator == "notNull":
@@ -313,9 +313,9 @@ class CommonQuerySet(QuerySet):
     def get_criteria(self, json=dict()):
         data = json.get('data', dict())
         _data = dict()
-        if data != None:
+        if data is not None:
             for key, value in data.items():
-                if value != None and key != 'full_name':
+                if value is not None and key != 'full_name':
                     setAttr(_data, key, value)
         data = _data
         delAttr(data, 'ts')
@@ -378,39 +378,39 @@ class CommonQuerySet(QuerySet):
 
         if isinstance(distinct_field_names, tuple) or (isinstance(distinct_field_names, list)):
             if self.alive_only == False:
-                if start != None and end != None:
+                if start is not None and end is not None:
                     queryResult = super().filter(*args, criteria).distinct(*distinct_field_names)[start:end]
-                elif start != None and end == None:
+                elif start is not None and end is None:
                     queryResult = super().filter(*args, criteria).distinct(*distinct_field_names)[start:]
-                elif end != None and start == None:
+                elif end is not None and start is None:
                     queryResult = super().filter(*args, criteria).distinct(*distinct_field_names)[:end]
                 else:
                     queryResult = super().filter(*args, criteria).distinct(*distinct_field_names)
             else:
-                if start != None and end != None:
+                if start is not None and end is not None:
                     queryResult = super().filter(*args, criteria).filter(deleted_at__isnull=True).distinct(*distinct_field_names)[start:end]
-                elif start != None and end == None:
+                elif start is not None and end is None:
                     queryResult = super().filter(*args, criteria).filter(deleted_at__isnull=True).distinct(*distinct_field_names)[start:]
-                elif end != None and start == None:
+                elif end is not None and start is None:
                     queryResult = super().filter(*args, criteria).filter(deleted_at__isnull=True).distinct(*distinct_field_names)[:end]
                 else:
                     queryResult = super().filter(*args, criteria).filter(deleted_at__isnull=True).distinct(*distinct_field_names)
         else:
             if self.alive_only == False:
-                if start != None and end != None:
+                if start is not None and end is not None:
                     queryResult = super().order_by(*ob).filter(*args, criteria).distinct()[start:end]
-                elif start != None and end == None:
+                elif start is not None and end is None:
                     queryResult = super().order_by(*ob).filter(*args, criteria)[start:]
-                elif end != None and start == None:
+                elif end is not None and start is None:
                     queryResult = super().order_by(*ob).filter(*args, criteria)[:end]
                 else:
                     queryResult = super().order_by(*ob).filter(*args, criteria)
             else:
-                if start != None and end != None:
+                if start is not None and end is not None:
                     queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)[start:end]
-                elif start != None and end == None:
+                elif start is not None and end is None:
                     queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)[start:]
-                elif end != None and start == None:
+                elif end is not None and start is None:
                     queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)[:end]
                 else:
                     queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)
@@ -595,7 +595,7 @@ class CommonManager(Manager):
         data = request.get_data()
         _data = data.copy()
 
-        if _data.get('parent') != None and isinstance(_data.get('parent'), int):
+        if _data.get('parent') is not None and isinstance(_data.get('parent'), int):
             setAttr(_data, 'parent_id', _data.get('parent'))
             delAttr(_data, 'parent')
 
@@ -780,7 +780,7 @@ class CommonManager(Manager):
             field = self.get_field(key)
             if isinstance(field, list):
                 field = field[0]
-            if field != None:
+            if field is not None:
                 if isinstance(field, ForeignKey):
                     setAttr(kwargs, f'{key}_id', val)
                 else:
@@ -815,11 +815,11 @@ class CommonManager(Manager):
 
         if field:
             # if field.null:
-            if field == None:
+            if field is None:
                 setAttr(_data, 'id', None)
                 res = _data
             else:
-                _data = {k: v for k, v in _data.items() if v != None}
+                _data = {k: v for k, v in _data.items() if v is not None}
                 if isinstance(_data, dict) and len(_data) > 0:
                     try:
                         res = field.related_model.objects.filter(**_data)
