@@ -26,7 +26,7 @@ class BaseRefQuerySet(AuditQuerySet):
             return super().filter(*args, **kwargs)
         else:
             full_name = kwargs.get('full_name')
-            if full_name != None:
+            if full_name is not None:
                 res = self.get_full_name_id(None, full_name[1:])
                 delAttr(kwargs, 'full_name')
                 setAttr(kwargs, 'pk', res.pk)
@@ -58,20 +58,20 @@ class BaseRefQuerySet(AuditQuerySet):
             res = super().get(*args, **kwargs)
         else:
             full_name = kwargs.get('full_name')
-            if full_name == None:
+            if full_name is None:
                 full_name = ''
             res = self.get_full_name_id(None, full_name[1:])
 
         return res
 
     def update(self, **kwargs):
-        if kwargs.get('code') == None and kwargs.get('name') != None:
+        if kwargs.get('code') is None and kwargs.get('name') is not None:
             setAttr(kwargs, 'code', AuditModel.uncapitalize(translit(kwargs.get('name'), reversed=True).replace("'", '').replace(' ', '_')))
         res = super().update(**kwargs)
         return res
 
     def create(self, **kwargs):
-        if kwargs.get('code') == None and kwargs.get('name') != None:
+        if kwargs.get('code') is None and kwargs.get('name') is not None:
             setAttr(kwargs, 'code', AuditModel.uncapitalize(translit(kwargs.get('name'), reversed=True).replace("'", '').replace(' ', '_')))
         res = super().create(**kwargs)
         return res
@@ -125,7 +125,7 @@ class BaseRef(AuditModel):
     description = DescriptionField()
 
     def save(self, *args, **kwargs):
-        if self.code == None:
+        if self.code is None:
             self.code = AuditModel.uncapitalize(translit(self.name, reversed=True).replace("'", '').replace(' ', '_').replace('-', '_'))
         super().save(*args, **kwargs)
 
@@ -202,7 +202,7 @@ class BaseRefHierarcy(Hierarcy):
     description = DescriptionField()
 
     def save(self, *args, **kwargs):
-        if self.code == None:
+        if self.code is None:
             self.code = AuditModel.uncapitalize(translit(self.name, reversed=True).replace("'", '').replace(' ', '_'))
         super().save(*args, **kwargs)
 
