@@ -25,6 +25,7 @@ class TreeAuditModelQuerySet(AuditQuerySet):
                         child_parent_value=None,
                         include_self=True,
                         where_clause='',
+                        where_clause1='',
                         order_by_clause='',
                         distinct='',
                         sql_text=None,
@@ -33,6 +34,9 @@ class TreeAuditModelQuerySet(AuditQuerySet):
                         ) -> RawQuerySet:
         db_name = self.model._meta.db_table
 
+        if where_clause1 == '' and where_clause != '':
+            where_clause1 = where_clause
+
         if limit is not None:
             if not isinstance(limit, int):
                 raise Exception(f'limit must be int.')
@@ -63,7 +67,7 @@ class TreeAuditModelQuerySet(AuditQuerySet):
                                     JOIN r
                                 ON {db_name}.{parent_id} = r.{child_id})
     
-                            select {distinct} {fields} from r {where_clause} {order_by_clause} limit %s offset %s
+                            select {distinct} {fields} from r {where_clause1} {order_by_clause} limit %s offset %s
                         '''
             # logger.debug(f'sql: {sql_text}')
             res = super().raw(sql_text, params=((id,), end, start))
@@ -82,7 +86,7 @@ class TreeAuditModelQuerySet(AuditQuerySet):
                                                 JOIN r
                                             ON {db_name}.{parent_id} = r.{child_id})
 
-                                        select {fields} from r {where_clause} {order_by_clause} limit %s offset %s
+                                        select {fields} from r {where_clause1} {order_by_clause} limit %s offset %s
                                     '''
             # logger.debug(f'sql: {sql_text}')
             res = super().raw(sql_text, params=(end, start))
@@ -176,6 +180,7 @@ class TreeAuditModelManager(AuditManager):
                         child_parent_value=None,
                         include_self=True,
                         where_clause='',
+                        where_clause1='',
                         order_by_clause='',
                         distinct='',
                         fields='*',
@@ -190,6 +195,7 @@ class TreeAuditModelManager(AuditManager):
             child_parent_value=child_parent_value,
             include_self=include_self,
             where_clause=where_clause,
+            where_clause1=where_clause1,
             order_by_clause=order_by_clause,
             distinct=distinct,
             fields=fields, sql_text=sql_text,
